## v0.1.3 (2024-10-15)

### Fix

- **models**: lowercased output fields

## v0.1.2 (2024-10-15)

### Fix

- **residentialhistoryadapter**: removed partner references

## v0.1.1 (2024-10-15)

### Fix

- **residentialhistoryadapter**: replaced root with rdf_root

## v0.1.0 (2024-10-15)

### Feat

- **all**: initial release
